ddst.twosample.test: Data Driven Smooth Test for Two-Sample Problem
Description
Performs data driven smooth test for the classical two-sample problem.
It is a special case of data driven test for k-samples.
Detailed description of the test statistic is provided in Wylupek (2010).
Usage
ddst.twosample.test(
x,
y,
d.N = 12,
c = 2,
B = 1e+05,
compute.p = TRUE,
alpha = 0.05,
compute.cv = TRUE
)
Arguments
x
a (non-empty) numeric vector of data
y
a (non-empty) numeric vector of data
d.N
an integer specifying the maximum dimension considered, only for advanced users
c
a calibrating parameter in the penalty in the model selection rule
B
an integer specifying the number of runs for a p-value and a critical value computation if any
compute.p
a logical value indicating whether to compute a p-value or not
alpha
a significance level
compute.cv
a logical value indicating whether to compute a critical value corresponding to the significance level alpha or not
set.seed(7)
# H0 is truex <- runif(80)
y <- runif(80)
t <- ddst.twosample.test(x, y)
t
plot(t)
# H0 is falsex <- runif(80)
y <- rexp(80, 1)
t <- ddst.twosample.test(x, y)
t
plot(t)